"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ad_records_1 = require("../records/ad.records");
const database_1 = require("../utils/database");
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield database_1.pool.end();
}));
const defaultObj = {
    name: 'Test Name',
    description: 'blah',
    url: 'http://megak.pl',
    price: 0,
    lat: 9,
    lon: 9,
};
test('AdRecord.getOne returns data from database for one entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_records_1.AdRecord.getOne('abc');
    console.log(ad);
    expect(ad).toBeDefined();
    expect(ad.id).toBe('abc');
    expect(ad.name).toBe('Testowa');
}));
test('AdRecord.getOne returns null from database for unexisting entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_records_1.AdRecord.getOne('---');
    expect(ad).toBeNull();
}));
test('AdRecord.findAll returns array of found entries.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_records_1.AdRecord.findAll('');
    expect(ads).not.toEqual([]);
    expect(ads[0]).toBeDefined();
}));
test('AdRecord.findAll returns array of found entries when searching for "a".', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_records_1.AdRecord.findAll('a');
    expect(ads).not.toEqual([]);
    expect(ads[0]).toBeDefined();
}));
test('AdRecord.findAll returns empty array when searching for something that does not exists.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_records_1.AdRecord.findAll('------------------------------');
    expect(ads).toEqual([]);
}));
test('AdRecord.findAll returns smaller amount of data.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_records_1.AdRecord.findAll('');
    expect(ads[0].id).toBeDefined();
    expect(ads[0].price).toBeUndefined();
    expect(ads[0].description).toBeUndefined();
}));
test('AdRecord.insert returns UUID.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = new ad_records_1.AdRecord(defaultObj);
    yield ad.insert();
    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');
}));
test('AdRecord.insert inserts data to database.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = new ad_records_1.AdRecord(defaultObj);
    yield ad.insert();
    const foundAd = yield ad_records_1.AdRecord.getOne(ad.id);
    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toBe(ad.id);
}));
//# sourceMappingURL=ad.test.js.map